multidim.PointCloud
===================

.. currentmodule:: multidim

.. autoclass:: PointCloud

   

      .. autosummary::
         :toctree:
      
         PointCloud.cache_usage
         PointCloud.cells
         PointCloud.check
         PointCloud.cover_ball
         PointCloud.dists
         PointCloud.from_distances
         PointCloud.from_multisample_multilabel
         PointCloud.gaussian_fit
         PointCloud.make_pers0
         PointCloud.make_pers1_rca1
         PointCloud.nearest_neighbors
         PointCloud.nearest_neighbors_slow
         PointCloud.plot
         PointCloud.reset
         PointCloud.sever
         PointCloud.unique_with_multiplicity
         PointCloud.witnessed_barycenters



   

